Index: Evidence/Edd/Edd.pro
===================================================================
--- Evidence/Edd/Edd.pro	(revision 224)
+++ Evidence/Edd/Edd.pro	(revision 229)
@@ -6,8 +6,8 @@
 TARGET = 
 DEPENDPATH += .
-INCLUDEPATH += . .. /ihp/local/qwt-5.2.1/include $(DIMDIR)/dim ../../drsdaq ../../pixelmap
+INCLUDEPATH += . .. $(QWTDIR)/include $(DIMDIR)/dim ../../drsdaq ../../pixelmap
 
 # Input
 HEADERS += Edd.h
 SOURCES += Edd.cc ../Evidence.cc ../../drsdaq/RawDataCTX.cc ../../pixelmap/Pixel.cc ../../pixelmap/PixelMap.cc
-LIBS += -L/ihp/local/qwt-5.2.1/lib -lqwt $(DIMDIR)/linux/libdim.a
+LIBS += -L$(QWTDIR)/lib -lqwt $(DIMDIR)/linux/libdim.a
Index: Evidence/Edd/INSTALL
===================================================================
--- Evidence/Edd/INSTALL	(revision 229)
+++ Evidence/Edd/INSTALL	(revision 229)
@@ -0,0 +1,44 @@
+Installation instructions for the Evidence Data Display Edd
+
+A) The packages Qt, Qwt and DIM are needed
+
+1. Qt can be downloaded from http://qt.nokia.com/. 
+
+   Test have been made with version 4.6.2 which can be downloaded aat
+   ftp://ftp.qt.nokia.com/qt/source/qt-everywhere-opensource-src-4.6.2.tar.gz.
+   It should well work with later version as well. 
+   
+   Installation instruction are given in the package. Usually, they amount on
+   Linux to executing './configure', then 'gmake all' followed by 
+   'gmake install', all done within the unpacked directory.
+ 
+   Before the following steps, it should be assured that the right version
+   of qmake is used, as many Linux installations include an older version
+   of Qt. Use 'qmake -version' to check and adjust your PATH variable if
+   necessary.
+    
+2. Qwt can be downloaded from http://sourceforge.net/projects/qwt/.
+   
+   Tests were made with version 5.2.1. Installation should simply be done
+   by executing 'qmake', then 'make', and finally 'make install'.
+
+3. DIM can be downloaded from http://dim.web.cern.ch/dim/.
+
+   The latest available version should be fine. Follow the installation
+   instruction on the web site given at the download link. Note that the
+   command line option in 'unzip -a' is mandatory. Compiling is done
+   with 'gmake all'.
+
+
+B) Compiling Edd
+
+An environment variable QWTDIR should point to the Qwt installation,
+and DIMDIR to the DIM installation.
+
+The subversion repository should preferably be checked out fully, as
+the class describing the M0 raw data format is currently needed.
+
+Issue 'qmake', then 'make' will build the executable Edd.
+
+To start, the environment variable LD_LIBRARY_PATH needs to include the
+location of the Qwt shared library. 

Index: Evidence/Edd/Edd.cc
===================================================================
--- Evidence/Edd/Edd.cc	(revision 224)
+++ Evidence/Edd/Edd.cc	(revision 229)
@@ -27,17 +27,26 @@
 QWidget *OpenHistory(char *Service, int Index) {
 
+  QString Format;
+  DimBrowser Browser;
   class EvidenceHistory *Hist = Handler->GetHistory(Service);
 
-  // Check if hitory service available
+  // Check if history service available
   if (Hist == NULL || Hist->GetFormat() == NULL) {
 	QMessageBox::warning(NULL, "Edd Message", QString("Could not retrieve history for service ") + Service ,QMessageBox::Ok);
-	Handler->DropHistory(Service);
-	return NULL;
-  }
-
-  QString Format = Hist->GetFormat();
+
+	// If service currently available, take its format
+	char *Name, *Fmt;
+
+	Browser.getServices(Service);
+	if (Browser.getNextService(Name, Fmt) != 0) Format = QString(Fmt);
+	else {
+	  Handler->DropHistory(Service);
+	  return NULL;
+	}
+  }
+
+  if (Format.isEmpty()) Format = Hist->GetFormat();
   Handler->DropHistory(Service);
   
-  //if (strlen(Hist->GetFormat()) == 1 && *Hist->GetFormat() != 'C') return new EddPlot(Service, Index);
   if (Format.size() == 1 && Format[0] != 'C') return new EddPlot(Service, Index);
   else return new EddText(Service);
@@ -68,5 +77,5 @@
 	QLineEdit(P), ServiceName(Name), Index(Index) {
 
- LastHist = NULL;
+  LastHist = NULL;
  
   // Widget properties
@@ -112,4 +121,5 @@
 	return;
   }
+  else Pal.setColor(QPalette::Base, Qt::white);
 
   // Message service backgound colour determined by severity 
@@ -933,7 +943,9 @@
   if (!EvidenceServer::ServiceOK(getInfo())) YEP(getInfo()->getName(), -1);
   else {
-	char *Text = EvidenceServer::ToString(getInfo());
-	YEP(getInfo()->getName(), getInfo()->getTimestamp(), QByteArray((char *) getInfo()->getData(), getInfo()->getSize()), getInfo()->getFormat(), Text);
-	free(Text);
+	YEP(getInfo()->getName(),
+		getInfo()->getTimestamp(),
+		QByteArray((char *) getInfo()->getData(), 
+		getInfo()->getSize()), getInfo()->getFormat(),
+		QString::fromStdString(EvidenceServer::ToString(getInfo())));
   }
 }
@@ -1183,9 +1195,13 @@
     Plot->AddService("ARDUINO/Data", i);
   }
-  Layout->addWidget(Plot, 0, 2, 8, 7);      
+  Layout->addWidget(Plot, 0, 2, 9, 7);      
 
   // Night sky monitor
+  Line = new EddLineDisplay("SQM/Message");
+  Line->setMaximumWidth(200);
+  Layout->addWidget(Line, 6, 0, 1, 2);      
+
   Line = new EddLineDisplay("SQM/NSB");
-  Layout->addWidget(Line, 6, 0, 1, 1);          
+  Layout->addWidget(Line, 7, 0, 1, 1);          
 }
 
@@ -1554,5 +1570,5 @@
   bool OK;
 
   // Find all services that are not history services and sort
   getServices("*");
   while ((Type = getNextService(Name, Format)) != 0) {
@@ -1554,5 +1570,5 @@
   bool OK;
 
-  // Find all services that are not history services and sort
+  // Find all DIM services and sort
   getServices("*");
   while ((Type = getNextService(Name, Format)) != 0) {